Learn R Programming

hts (version 3.03)

forecast.hts: Forecast a hierarchical or grouped time series

Description

Methods for forecasting hierarchical or grouped time series.

Usage

## S3 method for class 'gts':
forecast(object, h,
  method = c("comb", "bu", "mo", "tdgsf", "tdgsa", "tdfp", "all"),
  fmethod = c("ets", "rw", "arima"), level, positive = FALSE,
	xreg = NULL, newxreg = NULL, ...)

Arguments

object
Hierarchical time series object of class gts
h
Forecast horizon
method
Method for distributing forecasts within the hierarchy. See details
fmethod
Forecasting method to use
level
Level used for "middle-out" method (only used when method="mo")
positive
If TRUE, forecasts are forced to be strictly positive
xreg
When fmethod = "arima", a vector or matrix of external regressors, which must have the same number of rows as the original univariate time series
newxreg
When fmethod = "arima", a vector or matrix of external regressors, which must have the same number of rows as the original univariate time series
...
Other arguments passing to ets or auto.arima

Value

  • A forecasted hierarchical/grouped time series of class gts.

Details

Base methods implemented include ETS, ARIMA and the naive (random walk) models. Forecasts are distributed in the hierarchy using bottom-up, top-down, middle-out and optimal combination methods. Three top-down methods are available: the two Gross-Sohl methods and the forecast-proportion approach of Hyndman, Ahmed, and Athanasopoulos (2011). The "middle-out" method "mo" uses bottom-up ("bu") for levels higher than level and top-down forecast proportions ("tdfp") for levels lower than level. For non-hierarchical grouped data, only bottom-up and combination methods are possible, as any method involving top-down disaggregation requires a hierarchical ordering of groups.

References

G. Athanasopoulos, R. A. Ahmed and R. J. Hyndman (2009) Hierarchical forecasts for Australian domestic tourism, International Journal of Forecasting, 25, 146-166.

R. J. Hyndman, R. A. Ahmed, G. Athanasopoulos and H.L. Shang (2011) Optimal combination forecasts for hierarchical time series. Computational Statistics and Data Analysis, 55(9), 2579--2589. http://robjhyndman.com/papers/hierarchical/

Gross, C. and Sohl, J. (1990) Dissagregation methods to expedite product line forecasting, Journal of Forecasting, 9, 233-254.

See Also

hts, gts, plot.gts, accuracy.gts

Examples

Run this code
forecast(htseg1, h = 10, method = "bu")

Run the code above in your browser using DataLab