Learn R Programming

hts (version 3.03)

allts: Extract all time series from a gts object

Description

The time series from all levels of a hierarchical/grouped time series or a forecasted hierarchical/grouped time series are returned as a multivariate time series.

Usage

allts(obj, forecasts=TRUE)

Arguments

obj
An object of class gts.
forecasts
If obj contains forecasts and historical data, then forecasts indicates whether to return the forecasts or the historical data. Otherwise it is ignored.

Examples

Run this code
allts(htseg1)

Run the code above in your browser using DataLab